import typescript from 'rollup-plugin-typescript2'
import json from '@rollup/plugin-json';
import commonjs from '@rollup/plugin-commonjs';
import {nodeResolve} from '@rollup/plugin-node-resolve';
import {babel} from '@rollup/plugin-babel';
import { terser } from "rollup-plugin-terser";

export default [
    {
        input: 'src/index.ts',
        output: {
            file: 'dist/index.mjs',
            format: 'esm'
        },
        plugins: [
            typescript(),
            nodeResolve({
                browser: true,
            }),
            commonjs(),
            json(),
            babel({
                babelHelpers: 'inline'
            }),
            terser()
        ],
        external: ['axios', 'js-cookie', 'blueimp-md5', 'qs']
    },
    /**
     * umd 版本兼容es5
     */
    {
        input: 'src/index.ts',
        output: {
            file: 'dist/index.umd.js',
            name: 'YDLToolKit',
            format: 'umd',
            globals: {
                qs: 'qs',
                axios: 'axios',
                'js-cookie': 'Cookies',
                'blueimp-md5': 'md5'
            }
        },
        plugins: [
            typescript(),
            nodeResolve({
                browser: true,
            }),
            commonjs(),
            json(),
            babel({
                babelHelpers: 'inline'
            }),
            terser()
        ],
        external: ['axios', 'js-cookie', 'blueimp-md5', 'qs']
    }
]